summaryrefslogtreecommitdiff
path: root/svx/source/inc/fmtools.hxx
diff options
context:
space:
mode:
authorFrank Schönheit <fs@openoffice.org>2000-12-18 07:22:38 +0000
committerFrank Schönheit <fs@openoffice.org>2000-12-18 07:22:38 +0000
commit859e6499a71487d969dfb0a5bea9ca40539767d1 (patch)
tree8b49dff0412f972f9d4617148634be8a36e2aaeb /svx/source/inc/fmtools.hxx
parentb1549b9791b997568075882b4c1a911a8ddd4231 (diff)
#82151# put the string constants into a namespace - needed to disambiguate the symbols for solaris
Diffstat (limited to 'svx/source/inc/fmtools.hxx')
-rw-r--r--svx/source/inc/fmtools.hxx15
1 files changed, 10 insertions, 5 deletions
diff --git a/svx/source/inc/fmtools.hxx b/svx/source/inc/fmtools.hxx
index c19c85b09bbd..3db129ac234d 100644
--- a/svx/source/inc/fmtools.hxx
+++ b/svx/source/inc/fmtools.hxx
@@ -2,9 +2,9 @@
*
* $RCSfile: fmtools.hxx,v $
*
- * $Revision: 1.10 $
+ * $Revision: 1.11 $
*
- * last change: $Author: fs $ $Date: 2000-11-09 10:18:46 $
+ * last change: $Author: fs $ $Date: 2000-12-18 07:49:20 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -270,9 +270,14 @@ void displayException(const ::com::sun::star::sdb::SQLErrorEvent&, WinBits nStyl
#define S(aUniCode) \
::rtl::OUStringToOString(aUniCode, RTL_TEXTENCODING_ASCII_US)
-// modes for the XModeSelector
-DECLARE_CONSTASCII_USTRING(DATA_MODE);
-DECLARE_CONSTASCII_USTRING(FILTER_MODE);
+namespace svxform
+{
+
+ // modes for the XModeSelector
+ DECLARE_CONSTASCII_USTRING(DATA_MODE);
+ DECLARE_CONSTASCII_USTRING(FILTER_MODE);
+
+} // namespace svxform
// Kopieren von Persistenten Objecten